#!/usr/bin/python

from onelogin.api.util.utils import str2bool, str2int, str2date
from .base import Base


class FactorEnrollmentResponse(Base):
    def __init__(self, data):
        if "user_id" in data.keys():
            # v2
            self.id = data.get('id', None)
            self.user_id = str2int(data.get('user_id', None))
        else:
            # v1
            self.user_id = str2int(data.get('id', None))

        self.device_id = str2int(data.get('device_id', None))
        self.auth_factor_name = data.get('auth_factor_name', '')
        self.type_display_name = data.get('type_display_name', '')
        self.user_display_name = data.get('user_display_name', '')
        expires_at_data = data.get('state_token_expires_at', None)
        if expires_at_data is None:
            expires_at_data = data.get('expires_at', None)
        self.expires_at = str2date(expires_at_data)

        # v1
        if "state_token" in data.keys():
            self.state_token = data.get('state_token', '')
        if "active" in data.keys():
            self.active = str2bool(data.get('active', False))
        # v2
        if "factor_data" in data.keys():
            self.factor_data = data.get('factor_data', '')



# -*- coding: utf-8 -*-

""" Constants class

Copyright (c) 2021, OneLogin, Inc.
All rights reserved.

Constants class of the OneLogin's Python SDK.

"""


class Constants(object):
    """

    This class defines all the constants that will be used
    in the OneLogin's Python SDK.

    """

    # OAuth2 Tokens URLs
    TOKEN_REQUEST_URL = "https://%s.onelogin.com/auth/oauth2/v2/token"
    TOKEN_REFRESH_URL = "https://%s.onelogin.com/auth/oauth2/v2/token"
    TOKEN_REVOKE_URL = "https://%s.onelogin.com/auth/oauth2/revoke"
    GET_RATE_URL = "https://%s.onelogin.com/auth/rate_limit"

    # User URLs
    GET_USERS_URL = "https://%s.onelogin.com/api/%s/users"
    GET_USER_URL = "https://%s.onelogin.com/api/%s/users/%s"
    GET_APPS_FOR_USER_URL = "https://%s.onelogin.com/api/%s/users/%s/apps"
    GET_ROLES_FOR_USER_URL = "https://%s.onelogin.com/api/%s/users/%s/roles"
    GET_CUSTOM_ATTRIBUTES_URL = "https://%s.onelogin.com/api/%s/users/custom_attributes"
    CREATE_USER_URL = "https://%s.onelogin.com/api/%s/users"
    UPDATE_USER_URL = "https://%s.onelogin.com/api/%s/users/%s"
    DELETE_USER_URL = "https://%s.onelogin.com/api/%s/users/%s"
    ADD_ROLE_TO_USER_URL = "https://%s.onelogin.com/api/%s/users/%s/add_roles"
    DELETE_ROLE_TO_USER_URL = "https://%s.onelogin.com/api/%s/users/%s/remove_roles"
    SET_PW_CLEARTEXT = "https://%s.onelogin.com/api/%s/users/set_password_clear_text/%s"
    SET_PW_SALT = "https://%s.onelogin.com/api/%s/users/set_password_using_salt/%s"
    SET_STATE_TO_USER_URL = "https://%s.onelogin.com/api/%s/users/%s/set_state"
    SET_CUSTOM_ATTRIBUTE_TO_USER_URL = "https://%s.onelogin.com/api/%s/users/%s/set_custom_attributes"
    LOG_USER_OUT_URL = "https://%s.onelogin.com/api/%s/users/%s/logout"
    LOCK_USER_URL = "https://%s.onelogin.com/api/%s/users/%s/lock_user"
    GENERATE_MFA_TOKEN_URL = "https://%s.onelogin.com/api/%s/users/%s/mfa_token"

    # Connectors URLS
    GET_CONNECTORS_URL = "https://%s.onelogin.com/api/%s/connectors"

    # Apps URL
    GET_APPS_URL = "https://%s.onelogin.com/api/%s/apps"
    CREATE_APP_URL = "https://%s.onelogin.com/api/%s/apps"
    GET_APP_URL = "https://%s.onelogin.com/api/%s/apps/%s"
    UPDATE_APP_URL = "https://%s.onelogin.com/api/%s/apps/%s"
    DELETE_APP_URL = "https://%s.onelogin.com/api/%s/apps/%s"
    DELETE_APP_PARAMETER_URL = "https://%s.onelogin.com/api/%s/apps/%s/parameters/%s"
    GET_APP_USERS_URL = "https://%s.onelogin.com/api/%s/apps/%s/users"

    # App Rules URL
    GET_APP_RULES_URL = "https://%s.onelogin.com/api/%s/apps/%s/rules"
    CREATE_APP_RULE_URL = "https://%s.onelogin.com/api/%s/apps/%s/rules"
    GET_APP_RULE_URL = "https://%s.onelogin.com/api/%s/apps/%s/rules/%s"
    UPDATE_APP_RULE_URL = "https://%s.onelogin.com/api/%s/apps/%s/rules/%s"
    DELETE_APP_RULE_URL = "https://%s.onelogin.com/api/%s/apps/%s/rules/%s"
    GET_APP_CONDITIONS_URL = "https://%s.onelogin.com/api/%s/apps/%s/rules/conditions"
    GET_APP_CONDITION_OPERATORS_URL = "https://%s.onelogin.com/api/%s/apps/%s/rules/conditions/%s/operators"
    GET_APP_CONDITION_VALUES_URL = "https://%s.onelogin.com/api/%s/apps/%s/rules/conditions/%s/values"
    GET_APP_ACTIONS_URL = "https://%s.onelogin.com/api/%s/apps/%s/rules/actions"
    GET_APP_ACTION_VALUES_URL = "https://%s.onelogin.com/api/%s/apps/%s/rules/actions/%s/values"
    APP_RULE_SORT_URL = "https://%s.onelogin.com/api/%s/apps/%s/rules/sort"

    # Role URLs
    GET_ROLES_URL = "https://%s.onelogin.com/api/%s/roles"
    CREATE_ROLE_URL = "https://%s.onelogin.com/api/%s/roles"
    GET_ROLE_URL = "https://%s.onelogin.com/api/%s/roles/%s"
    UPDATE_ROLE_URL = "https://%s.onelogin.com/api/%s/roles/%s"
    GET_ROLE_APPS_URL = "https://%s.onelogin.com/api/%s/roles/%s/apps"
    SET_ROLE_APPS_URL = "https://%s.onelogin.com/api/%s/roles/%s/apps"
    GET_ROLE_USERS_URL = "https://%s.onelogin.com/api/%s/roles/%s/users"
    ADD_ROLE_USERS_URL = "https://%s.onelogin.com/api/%s/roles/%s/users"
    REMOVE_ROLE_USERS_URL = "https://%s.onelogin.com/api/%s/roles/%s/users"
    GET_ROLE_ADMINS_URL = "https://%s.onelogin.com/api/%s/roles/%s/admins"
    ADD_ROLE_ADMINS_URL = "https://%s.onelogin.com/api/%s/roles/%s/admins"
    REMOVE_ROLE_ADMINS_URL = "https://%s.onelogin.com/api/%s/roles/%s/admins"
    DELETE_ROLE_URL = "https://%s.onelogin.com/api/%s/roles/%s"

    # Event URLS
    GET_EVENT_TYPES_URL = "https://%s.onelogin.com/api/%s/events/types"
    GET_EVENTS_URL = "https://%s.onelogin.com/api/%s/events"
    CREATE_EVENT_URL = "https://%s.onelogin.com/api/%s/events"
    GET_EVENT_URL = "https://%s.onelogin.com/api/%s/events/%s"

    # Group URLs
    GET_GROUPS_URL = "https://%s.onelogin.com/api/%s/groups"
    CREATE_GROUP_URL = "https://%s.onelogin.com/api/%s/groups"
    GET_GROUP_URL = "https://%s.onelogin.com/api/%s/groups/%s"

    # Custom Login URLs
    SESSION_LOGIN_TOKEN_URL = "https://%s.onelogin.com/api/%s/login/auth"
    GET_TOKEN_VERIFY_FACTOR = "https://%s.onelogin.com/api/%s/login/verify_factor"

    # SAML Assertion URLs
    GET_SAML_ASSERTION_URL = "https://%s.onelogin.com/api/%s/saml_assertion"
    GET_SAML_VERIFY_FACTOR = "https://%s.onelogin.com/api/%s/saml_assertion/verify_factor"

    # Multi-Factor Authentication URLs
    GET_FACTORS_URL = "https://%s.onelogin.com/api/%s/users/%s/auth_factors"
    V2_GET_FACTORS_URL = "https://%s.onelogin.com/api/%s/mfa/users/%s/factors"
    ENROLL_FACTOR_URL = "https://%s.onelogin.com/api/%s/users/%s/otp_devices"
    V2_ENROLL_FACTOR_URL = "https://%s.onelogin.com/api/%s/mfa/users/%s/registrations"
    GET_ENROLLED_FACTORS_URL = "https://%s.onelogin.com/api/%s/users/%s/otp_devices"
    VERIFY_ENROLLMENT_SMS_EMAIL_PROTECT_AUTH_URL = "https://%s.onelogin.com/api/%s/mfa/users/%s/registrations/%s"
    VERIFY_ENROLLMENT__PROTECTPUSH_VOICE_URL = "https://%s.onelogin.com/api/%s/mfa/users/%s/registrations/%s"
    V2_GET_ENROLLED_FACTORS_URL = "https://%s.onelogin.com/api/%s/mfa/users/%s/devices"
    ACTIVATE_FACTOR_URL = "https://%s.onelogin.com/api/%s/users/%s/otp_devices/%s/trigger"
    V2_ACTIVATE_FACTOR_URL = "https://%s.onelogin.com/api/%s/mfa/users/%s/verifications"
    VERIFY_FACTOR_URL = "https://%s.onelogin.com/api/%s/users/%s/otp_devices/%s/verify"
    VERIFY_FACTOR_SMS_EMAIL_PROTECT_AUTH_URL = "https://%s.onelogin.com/api/%s/mfa/users/%s/verifications/%s"
    VERIFY_FACTOR_PROTECTPUSH_VOICE_URL = "https://%s.onelogin.com/api/%s/mfa/users/%s/verifications/%s"
    DELETE_FACTOR_URL = "https://%s.onelogin.com/api/%s/users/%s/otp_devices/%s"
    V2_DELETE_FACTOR_URL = "https://%s.onelogin.com/api/%s/mfa/users/%s/devices/%s"

    # Invite Link URLS
    GENERATE_INVITE_LINK_URL = "https://%s.onelogin.com/api/%s/invites/get_invite_link"
    SEND_INVITE_LINK_URL = "https://%s.onelogin.com/api/%s/invites/send_invite_link"

    # Embed Apps URL
    EMBED_APP_URL = "https://api.onelogin.com/client/apps/embed2"

    # Account Brands URLS
    GET_ACCOUNT_BRANDS_URL = "https://%s.onelogin.com/api/%s/branding/brands"
    CREATE_ACCOUNT_BRAND_URL = "https://%s.onelogin.com/api/%s/branding/brands"
    GET_ACCOUNT_BRAND_URL = "https://%s.onelogin.com/api/%s/branding/brands/%s"
    UPDATE_ACCOUNT_BRAND_URL = "https://%s.onelogin.com/api/%s/branding/brands/%s"
    DELETE_ACCOUNT_BRAND_URL = "https://%s.onelogin.com/api/%s/branding/brands/%s"
    GET_APPS_BRAND_URL = "https://%s.onelogin.com/api/%s/branding/%s/apps"
    GET_ACCOUNT_EMAIL_SETTINGS = "https://%s.onelogin.com/api/%s/branding/email_settings"
    UPDATE_ACCOUNT_EMAIL_SETTINGS = "https://%s.onelogin.com/api/%s/branding/email_settings"
    RESET_ACCOUNT_EMAIL_SETTINGS = "https://%s.onelogin.com/api/%s/branding/email_settings"

    # Smart Hooks URLS
    GET_HOOKS_URL = "https://%s.onelogin.com/api/%s/hooks"
    CREATE_HOOK_URL = "https://%s.onelogin.com/api/%s/hooks"
    GET_HOOK_URL = "https://%s.onelogin.com/api/%s/hooks/%s"
    UPDATE_HOOK_URL = "https://%s.onelogin.com/api/%s/hooks/%s"
    DELETE_HOOK_URL = "https://%s.onelogin.com/api/%s/hooks/%s"
    GET_HOOK_LOGS_URL = "https://%s.onelogin.com/api/%s/hooks/%s/logs"
    GET_HOOK_ENVS_URL = "https://%s.onelogin.com/api/%s/hooks/envs"
    CREATE_HOOK_ENV_URL = "https://%s.onelogin.com/api/%s/hooks/envs"
    GET_HOOK_ENV_URL = "https://%s.onelogin.com/api/%s/hooks/envs/%s"
    UPDATE_HOOK_ENV_URL = "https://%s.onelogin.com/api/%s/hooks/envs/%s"
    DELETE_HOOK_ENV_URL = "https://%s.onelogin.com/api/%s/hooks/envs/%s"

    # Smart MFA
    SMART_MFA_VALIDATE_USER = "https://%s.onelogin.com/api/%s/smart-mfa"
    SMART_MFA_VERFY_TOKEN = "https://%s.onelogin.com/api/%s/smart-mfa/verify"

    # Vigilance AI URLS
    TRACK_EVENT_URL = "https://%s.onelogin.com/api/%s/risk/events"
    GET_RISK_SCORE_URL = "https://%s.onelogin.com/api/%s/risk/verify"
    GET_RISK_RULES_URL = "https://%s.onelogin.com/api/%s/risk/rules"
    CREATE_RISK_RULE_URL = "https://%s.onelogin.com/api/%s/risk/rules"
    GET_RISK_RULE_URL = "https://%s.onelogin.com/api/%s/risk/rules/%s"
    UPDATE_RISK_RULE_URL = "https://%s.onelogin.com/api/%s/risk/rules/%s"
    DELETE_RISK_RULE_URL = "https://%s.onelogin.com/api/%s/risk/rules/%s"
    GET_SCORE_INSIGHTS = "https://%s.onelogin.com/api/%s/risk/scores"

    # Mappings URLS
    GET_MAPPINGS_URL = "https://%s.onelogin.com/api/%s/mappings"
    CREATE_MAPPING_URL = "https://%s.onelogin.com/api/%s/mappings"
    GET_MAPPING_URL = "https://%s.onelogin.com/api/%s/mappings/%s"
    UPDATE_MAPPING_URL = "https://%s.onelogin.com/api/%s/mappings/%s"
    DELETE_MAPPING_URL = "https://%s.onelogin.com/api/%s/mappings/%s"
    DRYRUN_MAPPING_URL = "https://%s.onelogin.com/api/%s/mappings/%s/dryrun"
    GET_MAPPING_CONDITIONS_URL = "https://%s.onelogin.com/api/%s/mappings/conditions"
    GET_MAPPING_CONDITION_OPERATORS_URL = "https://%s.onelogin.com/api/%s/mappings/conditions/%s/operators"
    GET_MAPPING_CONDITION_VALUES_URL = "https://%s.onelogin.com/api/%s/mappings/conditions/%s/values"
    GET_MAPPING_ACTIONS_URL = "https://%s.onelogin.com/api/%s/mappings/actions"
    GET_MAPPING_ACTION_VALUES_URL = "https://%s.onelogin.com/api/%s/mappings/actions/%s/values"
    MAPPING_SORT_URL = "https://%s.onelogin.com/api/%s/mappings/sort"

    # Privileges URLS
    LIST_PRIVILEGES_URL = "https://%s.onelogin.com/api/%s/privileges"
    CREATE_PRIVILEGE_URL = "https://%s.onelogin.com/api/%s/privileges"
    UPDATE_PRIVILEGE_URL = "https://%s.onelogin.com/api/%s/privileges/%s"
    GET_PRIVILEGE_URL = "https://%s.onelogin.com/api/%s/privileges/%s"
    DELETE_PRIVILEGE_URL = "https://%s.onelogin.com/api/%s/privileges/%s"
    GET_ROLES_ASSIGNED_TO_PRIVILEGE_URL = "https://%s.onelogin.com/api/%s/privileges/%s/roles"
    ASSIGN_ROLES_TO_PRIVILEGE_URL = "https://%s.onelogin.com/api/%s/privileges/%s/roles"
    REMOVE_ROLE_FROM_PRIVILEGE_URL = "https://%s.onelogin.com/api/%s/privileges/%s/roles/%s"
    GET_USERS_ASSIGNED_TO_PRIVILEGE_URL = "https://%s.onelogin.com/api/%s/privileges/%s/users"
    ASSIGN_USERS_TO_PRIVILEGE_URL = "https://%s.onelogin.com/api/%s/privileges/%s/users"
    REMOVE_USER_FROM_PRIVILEGE_URL = "https://%s.onelogin.com/api/%s/privileges/%s/users/%s"
    VALID_ACTIONS = [
        "apps:List",
        "apps:Get",
        "apps:Create",
        "apps:Update",
        "apps:Delete",
        "apps:ManageRoles",
        "apps:ManageUsers",
        "directories:List",
        "directories:Get",
        "directories:Create",
        "directories:Update",
        "directories:Delete",
        "directories:SyncUsers",
        "directories:RefreshSchema",
        "events:List",
        "events:Get",
        "mappings:List",
        "mappings:Get",
        "mappings:Create",
        "mappings:Update",
        "mappings:Delete",
        "mappings:ReapplyAll",
        "policies:List",
        "policies:user:Get",
        "policies:user:Create",
        "policies:user:Update",
        "policies:user:Delete",
        "policies:app:Get",
        "policies:app:Create",
        "policies:app:Update",
        "policies:app:Delete",
        "privileges:List",
        "privileges:Get",
        "privileges:Create",
        "privileges:Update",
        "privileges:Delete",
        "privileges:ListUsers",
        "privileges:ListRoles",
        "privileges:ManageUsers",
        "privileges:ManageRoles",
        "reports:List",
        "reports:Get",
        "reports:Create",
        "reports:Update",
        "reports:Delete",
        "reports:Run",
        "roles:List",
        "roles:Get",
        "roles:Create",
        "roles:Update",
        "roles:Delete",
        "roles:ManageUsers",
        "roles:ManageApps",
        "trustedidp:List",
        "trustedidp:Get",
        "trustedidp:Create",
        "trustedidp:Update",
        "trustedidp:Delete",
        "users:List",
        "users:Get",
        "users:Create",
        "users:Update",
        "users:Delete",
        "users:Unlock",
        "users:ResetPassword",
        "users:ForceLogout",
        "users:Invite",
        "users:ReapplyMappings",
        "users:ManageRoles",
        "users:ManageApps",
        "users:GenerateTempMfaToken"
    ]



#!/usr/bin/python

from onelogin.api.util.utils import str2int, str2date
from .base import Base


class OneLoginToken(Base):
    def __init__(self, data):
        self.access_token = data['access_token']
        self.refresh_token = data['refresh_token']
        self.account_id = str2int(data.get('account_id', None))
        self.token_type = data['token_type']
        self.created_at = str2date(data.get('created_at', None))
        self.expires_in = str2int(data.get('expires_in', None))



#!/usr/bin/python

from onelogin.api.util.utils import str2int, str2bool

from .base import Base


class Rule(Base):
    def __init__(self, data):
        self.id = str2int(data.get('id', None))
        self.name = data.get('name', None)
        self.match = data.get('match', None)
        self.enabled = str2bool(data.get('enabled', None))
        self.position = str2int(data.get('position', None))
        self.conditions = data.get('conditions', None)
        self.actions = data.get('actions', None)



#!/usr/bin/python

from onelogin.api.util.utils import str2int, str2bool, str2date

from .base import Base


class SmartHook(Base):
    def __init__(self, data):
        self.id = data.get('id', None)
        self.type = data.get('type', '')
        self.packages = data.get('packages', None)
        self.runtime = data.get('runtime', None)
        self.context_version = data.get('context_version', None)
        self.retries = str2int(data.get('retries', None))
        self.timeout = str2int(data.get('timeout', None))
        self.disabled = str2bool(data.get('disabled', True))
        self.status = data.get('status', None)
        self.env_vars = data.get('env_vars', None)
        self.risk_enabled = str2bool(data.get('risk_enabled', False))
        self.location_enabled = str2bool(data.get('location_enabled', False))
        self.mfa_device_info_enabled = str2bool(data.get('mfa_device_info_enabled', False))
        self.activated_at = str2date(data.get('activated_at', None))
        self.updated_at = str2date(data.get('updated_at', None))
        self.function = data.get('function', None)



#!/usr/bin/python


def exception_handler(func):
    def decorator(self, *args, **kwargs):
        try:
            return func(self, *args, **kwargs)
        except Exception as e:
            self.error = 500
            self.error_description = e.args[0]

    return decorator


def exception_handler_return_false(func):
    def decorator(self, *args, **kwargs):
        try:
            return func(self, *args, **kwargs)
        except Exception as e:
            self.error = 500
            self.error_description = e.args[0]
        return False

    return decorator



#!/usr/bin/python

from onelogin.api.util.utils import str2int, str2bool

from .base import Base


class EmbedApp(Base):
    def __init__(self, data):
        self.id = str2int(data.get('id', None))
        self.name = data.get('name', '')
        self.icon = data.get('icon', '')
        self.provisioned = str2bool(data.get('provisioned', None))
        self.extension_required = str2bool(data.get('extension_required', None))
        self.login_id = str2int(data.get('login_id', None))
        self.personal = str2bool(data.get('personal', None))



#!/usr/bin/python

from onelogin.api.util.utils import str2int

from .base import Base


class RiskScore(Base):
    def __init__(self, data):
        self.score = str2int(data.get('score', None))
        self.risk_level = data.get('risk_level', None)
        self.triggers = data.get('triggers', None)
        self.messages = data.get('messages', None)



#!/usr/bin/python

from onelogin.api.util.utils import str2int

from .base import Base


class AssignedBase(Base):

    def __init__(self, data):
        self.id = str2int(data.get('id', None))
        self.name = data.get('name', None)
        self.email = data.get('email', None)
        self.username = data.get('username', None)
        self.assigned = data.get('assigned', None)
        self.added_by = data.get('added_by', None)

    def get_added_by(self):
        return self.added_by



#!/usr/bin/python

from onelogin.api.util.utils import str2bool, str2int

from .app import App


class UserApp(App):
    def __init__(self, data):
        super(UserApp, self).__init__(data)
        self.extension = str2bool(data.get('extension', None))
        self.login_id = str2int(data.get('login_id', None))
        # v1
        if 'personal' in data.keys():
            self.personal = str2bool(data.get('personal', None))
        if 'provisioned' in data.keys():
            self.provisioned = str2bool(data.get('provisioned', None))
        # v2
        if 'provisioning_status' in data.keys():
            self.provisioning_status = data.get('provisioning_status', None)
            self.provisioning_state = data.get('provisioning_state', None)
            self.provisioning_enabled = data.get('provisioning_enabled', None)



#!/usr/bin/python

from onelogin.api.util.utils import str2date

from .base import Base


class MFAToken(Base):
    def __init__(self, data):
        self.value = data.get('mfa_token', None)
        self.reusable = data.get('reusable', None)
        self.expires_at = str2date(data.get('expires_at', None))



#!/usr/bin/python

from onelogin.api.util.utils import str2int

from .base import Base


class RiskScoreInsights(Base):
    def __init__(self, data):
        self.scores = data.get('scores', None)
        self.total = str2int(data.get('total', None))
